/* Emacs: this is -*- C -*- code, */
/* generated 2014-05-17T03:05:24-07 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_6 7
#define LABEL_7 9
#define LABEL_10 11
#define LABEL_9 13
#define LABEL_13 15
#define LABEL_11 17
#define LABEL_15 19
#define LABEL_18 21
#define TAG_19 9
#define LABEL_21 23
#define LABEL_16 25
#define TAG_17 11
#define LABEL_23 27
#define LABEL_24 29
#define LABEL_25 31
#define LABEL_22 33
#define LABEL_26 35
#define LABEL_27 37
#define TAG_28 17
#define LABEL_34 39
#define LABEL_35 41
#define LABEL_36 43
#define LABEL_37 45
#define LABEL_38 47
#define LABEL_39 49
#define LABEL_30 51
#define LABEL_31 53
#define TAG_32 25
#define LABEL_40 55
#define LABEL_41 57
#define TAG_42 27
#define LABEL_43 59
#define LABEL_44 61
#define LABEL_52 63
#define LABEL_45 65
#define LABEL_46 67
#define LABEL_47 69
#define LABEL_56 71
#define LABEL_57 73
#define LABEL_58 75
#define LABEL_59 77
#define LABEL_60 79
#define LABEL_61 81
#define LABEL_62 83
#define LABEL_63 85
#define LABEL_65 87
#define LABEL_66 89
#define LABEL_67 91
#define LABEL_68 93
#define LABEL_69 95
#define LABEL_70 97
#define LABEL_48 99
#define LABEL_72 101
#define LABEL_73 103
#define LABEL_74 105
#define LABEL_75 107
#define LABEL_77 109
#define LABEL_49 111
#define LABEL_50 113
#define TAG_51 55
#define LABEL_81 115
#define LABEL_54 117
#define TAG_55 57
#define LABEL_82 119
#define LABEL_64 121
#define LABEL_84 123
#define LABEL_85 125
#define LABEL_86 127
#define LABEL_87 129
#define LABEL_88 131
#define LABEL_89 133
#define LABEL_76 135
#define LABEL_78 137
#define TAG_79 67
#define LABEL_93 139
#define LABEL_94 141
#define LABEL_95 143
#define LABEL_99 145
#define LABEL_100 147
#define LABEL_83 149
#define LABEL_90 151
#define LABEL_103 153
#define LABEL_91 155
#define TAG_92 76
#define LABEL_106 157
#define LABEL_97 159
#define LABEL_107 161
#define LABEL_96 163
#define LABEL_108 165
#define LABEL_109 167
#define LABEL_110 169
#define LABEL_111 171
#define LABEL_112 173
#define LABEL_98 175
#define LABEL_102 177
#define LABEL_113 179
#define LABEL_114 181
#define LABEL_104 183
#define TAG_105 90
#define LABEL_117 185
#define LABEL_115 187
#define LABEL_118 189
#define LABEL_119 191
#define LABEL_120 193
#define LABEL_121 195
#define LABEL_122 197
#define LABEL_123 199
#define ENVIRONMENT_LABEL_3 254
#define DEBUGGING_LABEL_2 253
#define OBJECT_25 252
#define OBJECT_24 251
#define OBJECT_23 250
#define OBJECT_22 249
#define OBJECT_21 248
#define OBJECT_20 247
#define OBJECT_19 246
#define OBJECT_18 245
#define OBJECT_17 244
#define OBJECT_16 243
#define OBJECT_15 242
#define OBJECT_14 241
#define OBJECT_13 240
#define OBJECT_12 239
#define OBJECT_11 238
#define OBJECT_10 237
#define OBJECT_9 236
#define OBJECT_8 235
#define OBJECT_7 234
#define OBJECT_6 233
#define OBJECT_5 232
#define OBJECT_4 231
#define OBJECT_3 230
#define OBJECT_2 229
#define OBJECT_1 228
#define OBJECT_0 227
#define EXECUTE_CACHE_116 201
#define EXECUTE_CACHE_101 203
#define EXECUTE_CACHE_80 205
#define EXECUTE_CACHE_71 207
#define EXECUTE_CACHE_53 209
#define EXECUTE_CACHE_33 211
#define EXECUTE_CACHE_29 213
#define EXECUTE_CACHE_20 215
#define EXECUTE_CACHE_14 217
#define EXECUTE_CACHE_12 219
#define EXECUTE_CACHE_8 221
#define FREE_REFERENCE_0 224
#define FREE_ASSIGNMENT_0 226
#define FREE_REFERENCES_LABEL_0 200
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
ralloc_so_2e0edaa2f68719e7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
  machine_word Wrd99;
  machine_word Wrd116;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd85;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd48;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd46;
  machine_word Wrd44;
  machine_word Wrd66;
  machine_word Wrd57;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd84;
  machine_word Wrd171;
  machine_word Wrd168;
  machine_word Wrd158;
  machine_word Wrd157;
  machine_word Wrd155;
  machine_word Wrd165;
  machine_word Wrd164;
  machine_word Wrd163;
  machine_word Wrd162;
  machine_word Wrd160;
  machine_word Wrd159;
  machine_word Wrd166;
  machine_word Wrd153;
  machine_word Wrd150;
  machine_word Wrd141;
  machine_word Wrd147;
  machine_word Wrd146;
  machine_word Wrd145;
  machine_word Wrd148;
  machine_word Wrd134;
  machine_word Wrd135;
  machine_word Wrd140;
  machine_word Wrd139;
  machine_word Wrd136;
  machine_word Wrd133;
  machine_word Wrd130;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd127;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd124;
  machine_word Wrd121;
  machine_word Wrd128;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd174;
  machine_word Wrd87;
  machine_word Wrd83;
  machine_word Wrd69;
  machine_word Wrd80;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd81;
  machine_word Wrd68;
  machine_word Wrd56;
  machine_word Wrd49;
  machine_word Wrd50;
  machine_word Wrd177;
  machine_word Wrd22;
  machine_word Wrd82;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd58;
  machine_word Wrd51;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd72;
  machine_word Wrd65;
  machine_word Wrd71;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd122;
  machine_word Wrd115;
  machine_word Wrd119;
  machine_word Wrd118;
  machine_word Wrd114;
  machine_word Wrd111;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd96;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd91;
  machine_word Wrd86;
  machine_word Wrd106;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd100;
  machine_word Wrd98;
  machine_word Wrd97;
  machine_word Wrd110;
  machine_word Wrd109;
  machine_word Wrd108;
  machine_word Wrd107;
  machine_word Wrd47;
  machine_word Wrd123;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd13;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd45;
  machine_word Wrd37;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd23;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd14;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto continuation_6;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto register_allocation_5;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto lambda_4;

    case 4:
      current_block = (Rpc - LABEL_10);
      goto label_117;

    case 5:
      current_block = (Rpc - LABEL_9);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_13);
      goto label_118;

    case 7:
      current_block = (Rpc - LABEL_11);
      goto continuation_8;

    case 8:
      current_block = (Rpc - LABEL_15);
      goto label_119;

    case 9:
      current_block = (Rpc - LABEL_18);
      goto lambda_179;

    case 10:
      current_block = (Rpc - LABEL_21);
      goto label_120;

    case 11:
      current_block = (Rpc - LABEL_16);
      goto swapB_178;

    case 12:
      current_block = (Rpc - LABEL_23);
      goto label_121;

    case 13:
      current_block = (Rpc - LABEL_24);
      goto label_122;

    case 14:
      current_block = (Rpc - LABEL_25);
      goto label_123;

    case 15:
      current_block = (Rpc - LABEL_22);
      goto continuation_22;

    case 16:
      current_block = (Rpc - LABEL_26);
      goto continuation_31;

    case 17:
      current_block = (Rpc - LABEL_27);
      goto lambda_180;

    case 18:
      current_block = (Rpc - LABEL_34);
      goto label_124;

    case 19:
      current_block = (Rpc - LABEL_35);
      goto label_125;

    case 20:
      current_block = (Rpc - LABEL_36);
      goto label_126;

    case 21:
      current_block = (Rpc - LABEL_37);
      goto label_127;

    case 22:
      current_block = (Rpc - LABEL_38);
      goto label_129;

    case 23:
      current_block = (Rpc - LABEL_39);
      goto label_128;

    case 24:
      current_block = (Rpc - LABEL_30);
      goto continuation_33;

    case 25:
      current_block = (Rpc - LABEL_31);
      goto lambda_181;

    case 26:
      current_block = (Rpc - LABEL_40);
      goto continuation_52;

    case 27:
      current_block = (Rpc - LABEL_41);
      goto lambda_182;

    case 28:
      current_block = (Rpc - LABEL_43);
      goto continuation_53;

    case 29:
      current_block = (Rpc - LABEL_44);
      goto continuation_34;

    case 30:
      current_block = (Rpc - LABEL_52);
      goto label_130;

    case 31:
      current_block = (Rpc - LABEL_45);
      goto continuation_75;

    case 32:
      current_block = (Rpc - LABEL_46);
      goto continuation_74;

    case 33:
      current_block = (Rpc - LABEL_47);
      goto allocate_P_102;

    case 34:
      current_block = (Rpc - LABEL_56);
      goto label_131;

    case 35:
      current_block = (Rpc - LABEL_57);
      goto label_132;

    case 36:
      current_block = (Rpc - LABEL_58);
      goto label_133;

    case 37:
      current_block = (Rpc - LABEL_59);
      goto label_134;

    case 38:
      current_block = (Rpc - LABEL_60);
      goto label_135;

    case 39:
      current_block = (Rpc - LABEL_61);
      goto label_136;

    case 40:
      current_block = (Rpc - LABEL_62);
      goto label_137;

    case 41:
      current_block = (Rpc - LABEL_63);
      goto label_138;

    case 42:
      current_block = (Rpc - LABEL_65);
      goto label_139;

    case 43:
      current_block = (Rpc - LABEL_66);
      goto label_140;

    case 44:
      current_block = (Rpc - LABEL_67);
      goto label_141;

    case 45:
      current_block = (Rpc - LABEL_68);
      goto label_142;

    case 46:
      current_block = (Rpc - LABEL_69);
      goto label_143;

    case 47:
      current_block = (Rpc - LABEL_70);
      goto label_144;

    case 48:
      current_block = (Rpc - LABEL_48);
      goto continuation_73;

    case 49:
      current_block = (Rpc - LABEL_72);
      goto renumbered_registers_83;

    case 50:
      current_block = (Rpc - LABEL_73);
      goto label_145;

    case 51:
      current_block = (Rpc - LABEL_74);
      goto label_148;

    case 52:
      current_block = (Rpc - LABEL_75);
      goto label_146;

    case 53:
      current_block = (Rpc - LABEL_77);
      goto label_147;

    case 54:
      current_block = (Rpc - LABEL_49);
      goto continuation_39;

    case 55:
      current_block = (Rpc - LABEL_50);
      goto lambda_183;

    case 56:
      current_block = (Rpc - LABEL_81);
      goto label_149;

    case 57:
      current_block = (Rpc - LABEL_54);
      goto lambda_184;

    case 58:
      current_block = (Rpc - LABEL_82);
      goto label_150;

    case 59:
      current_block = (Rpc - LABEL_64);
      goto continuation_96;

    case 60:
      current_block = (Rpc - LABEL_84);
      goto label_151;

    case 61:
      current_block = (Rpc - LABEL_85);
      goto label_152;

    case 62:
      current_block = (Rpc - LABEL_86);
      goto label_153;

    case 63:
      current_block = (Rpc - LABEL_87);
      goto label_154;

    case 64:
      current_block = (Rpc - LABEL_88);
      goto label_155;

    case 65:
      current_block = (Rpc - LABEL_89);
      goto label_156;

    case 66:
      current_block = (Rpc - LABEL_76);
      goto continuation_82;

    case 67:
      current_block = (Rpc - LABEL_78);
      goto lambda_187;

    case 68:
      current_block = (Rpc - LABEL_93);
      goto loop_70;

    case 69:
      current_block = (Rpc - LABEL_94);
      goto label_157;

    case 70:
      current_block = (Rpc - LABEL_95);
      goto label_158;

    case 71:
      current_block = (Rpc - LABEL_99);
      goto label_159;

    case 72:
      current_block = (Rpc - LABEL_100);
      goto label_160;

    case 73:
      current_block = (Rpc - LABEL_83);
      goto continuation_101;

    case 74:
      current_block = (Rpc - LABEL_90);
      goto continuation_42;

    case 75:
      current_block = (Rpc - LABEL_103);
      goto label_161;

    case 76:
      current_block = (Rpc - LABEL_91);
      goto lambda_188;

    case 77:
      current_block = (Rpc - LABEL_106);
      goto label_162;

    case 78:
      current_block = (Rpc - LABEL_97);
      goto continuation_68;

    case 79:
      current_block = (Rpc - LABEL_107);
      goto label_168;

    case 80:
      current_block = (Rpc - LABEL_96);
      goto continuation_62;

    case 81:
      current_block = (Rpc - LABEL_108);
      goto label_167;

    case 82:
      current_block = (Rpc - LABEL_109);
      goto label_163;

    case 83:
      current_block = (Rpc - LABEL_110);
      goto label_164;

    case 84:
      current_block = (Rpc - LABEL_111);
      goto label_166;

    case 85:
      current_block = (Rpc - LABEL_112);
      goto label_165;

    case 86:
      current_block = (Rpc - LABEL_98);
      goto continuation_67;

    case 87:
      current_block = (Rpc - LABEL_102);
      goto continuation_47;

    case 88:
      current_block = (Rpc - LABEL_113);
      goto label_169;

    case 89:
      current_block = (Rpc - LABEL_114);
      goto label_170;

    case 90:
      current_block = (Rpc - LABEL_104);
      goto lambda_190;

    case 91:
      current_block = (Rpc - LABEL_117);
      goto label_171;

    case 92:
      current_block = (Rpc - LABEL_115);
      goto continuation_105;

    case 93:
      current_block = (Rpc - LABEL_118);
      goto label_172;

    case 94:
      current_block = (Rpc - LABEL_119);
      goto continuation_108;

    case 95:
      current_block = (Rpc - LABEL_120);
      goto label_174;

    case 96:
      current_block = (Rpc - LABEL_121);
      goto label_173;

    case 97:
      current_block = (Rpc - LABEL_122);
      goto label_191;

    case 98:
      current_block = (Rpc - LABEL_123);
      goto expression_116;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_116)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_122])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_191)
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1]), 3);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_5);
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (register_allocation_176)
DEFLABEL (register_allocation_5)
  INTERRUPT_CHECK (26, LABEL_6);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (lambda_177)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_195;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_195;
  (Wrd11.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_194)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd29.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_11);
  (Wrd5.Obj) = Rvl;
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 10))
    goto label_193;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd32.Lng))))
    goto label_193;
  ((Wrd30.pObj) [4]) = Rvl;

DEFLABEL (label_192)
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-1]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_16])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  ((Wrd23.pObj) [2]) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18])));
  Rhp += 2;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd15 = Wrd12;
  ((Wrd15.pObj) [2]) = (Wrd9.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [3]) = (Wrd14.Obj);
  (Rsp [2]) = (Wrd11.Obj);
  (Rsp [3]) = (Wrd24.Obj);
  (Rsp [1]) = (Wrd24.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20]));

DEFLABEL (label_193)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (current_block [OBJECT_8]);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_119)
  goto label_192;

DEFLABEL (label_195)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.Obj) = (current_block [OBJECT_4]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_117)
  (* (--Rsp)) = Rvl;
  goto label_194;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9);
  (Rsp [0]) = Rvl;
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd7.uLng) == 26))
    goto label_198;
  (Wrd9.Lng) = (FIXNUM_TO_LONG (Rvl));
  if ((Wrd9.Lng) > 1000000L)
    goto label_197;

DEFLABEL (label_196)
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_197)
  (Wrd14.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14]));

DEFLABEL (label_198)
  (Wrd16.Obj) = (current_block [OBJECT_6]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (37);

DEFLABEL (label_118)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_196;
  goto label_197;

DEFLABEL (lambda_179)
  CLOSURE_HEADER (LABEL_18);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd23.Obj) = ((Wrd6.pObj) [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 10))
    goto label_200;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd20.Lng))))
    goto label_200;
  (Wrd8.Obj) = ((Wrd18.pObj) [3]);

DEFLABEL (label_199)
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd36.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_22);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_4]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_28);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_27])));
  Rhp += 2;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd16 = Wrd13;
  ((Wrd16.pObj) [2]) = Rvl;
  ((Wrd16.pObj) [3]) = (Wrd7.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_32);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_31])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33]));

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_30);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_42);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_41])));
  Rhp += 3;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd15 = Wrd10;
  (Wrd16.Obj) = (Rsp [4]);
  ((Wrd15.pObj) [2]) = (Wrd16.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  ((Wrd15.pObj) [3]) = (Wrd14.Obj);
  ((Wrd15.pObj) [4]) = Rvl;
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_43);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (current_block [OBJECT_4]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.pObj) = (& (Rsp [7]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd23.Obj);
  goto renumbered_registers_83;

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_48);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71]));

DEFLABEL (continuation_74)
  INTERRUPT_CHECK (27, LABEL_46);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_55);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_54])));
  Rhp += 5;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd15 = Wrd6;
  (Wrd16.Obj) = (Rsp [6]);
  ((Wrd15.pObj) [2]) = (Wrd16.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  ((Wrd15.pObj) [3]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  ((Wrd15.pObj) [4]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  ((Wrd15.pObj) [5]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd15.pObj) [6]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_45);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [7]));
  goto pop_return;

DEFLABEL (label_200)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [2]);
  (Wrd28.Obj) = (current_block [OBJECT_10]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_120)
  (Wrd8.Obj) = Rvl;
  goto label_199;

DEFLABEL (swapB_178)
  CLOSURE_HEADER (LABEL_16);

DEFLABEL (swapB_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_209;

DEFLABEL (label_208)
  Wrd5 = Wrd9;

DEFLABEL (label_207)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_0]));
  (Wrd18.Obj) = (MAKE_OBJECT (50, 0));
  (Wrd27.Obj) = ((Wrd17.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_206;

DEFLABEL (label_205)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_204)
  (Wrd32.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd37.Obj) = ((Wrd36.pObj) [0]);
  (* (--Rsp)) = (Wrd37.Obj);
  ((Wrd36.pObj) [0]) = (Wrd32.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd45.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_0]));
  (Wrd53.Obj) = ((Wrd45.pObj) [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd54.uLng) == 50)
    goto label_203;

DEFLABEL (label_202)
  ((Wrd45.pObj) [0]) = (Wrd37.Obj);

DEFLABEL (label_201)
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_203)
  if ((Wrd53.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_202;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_25])), (Wrd45.pObj), (Wrd37.Obj));

DEFLABEL (label_123)
  goto label_201;

DEFLABEL (label_206)
  if ((Wrd27.Obj) == (Wrd18.Obj))
    goto label_205;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_24])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_122)
  goto label_204;

DEFLABEL (label_209)
  if ((Wrd9.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_208;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_23])), (Wrd6.pObj));

DEFLABEL (label_121)
  (Wrd5.Obj) = Rvl;
  goto label_207;

DEFLABEL (lambda_180)
  CLOSURE_HEADER (LABEL_27);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_222;
  Wrd6 = Wrd10;

DEFLABEL (label_221)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_220;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd18.Lng))))
    goto label_220;
  (Wrd12.Obj) = ((Wrd16.pObj) [5]);

DEFLABEL (label_219)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_218;
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 26))
    goto label_218;
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd33.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_218;
  (Wrd27.uLng) = (OBJECT_DATUM (Wrd30.Obj));
  (Wrd29.pObj) = (& ((Wrd34.pObj) [(Wrd27.Lng)]));
  (Wrd25.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_217)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd43.uLng) == 26))
    goto label_216;
  (Wrd123.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if ((Wrd123.Lng) > 0)
    goto label_211;

DEFLABEL (label_210)
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_211)
  (Wrd107.Obj) = (Rsp [0]);
  (Wrd108.pObj) = (OBJECT_ADDRESS (Wrd107.Obj));
  (Wrd109.Obj) = ((Wrd108.pObj) [2]);
  (Wrd110.uLng) = (OBJECT_TYPE (Wrd109.Obj));
  if (! ((Wrd110.uLng) == 10))
    goto label_215;
  (Wrd97.Obj) = (Rsp [1]);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd98.uLng) == 26))
    goto label_215;
  (Wrd100.Lng) = (FIXNUM_TO_LONG (Wrd97.Obj));
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd109.Obj));
  (Wrd105.Obj) = ((Wrd104.pObj) [0]);
  (Wrd106.Lng) = (FIXNUM_TO_LONG (Wrd105.Obj));
  if (! (((unsigned long) (Wrd100.Lng)) < ((unsigned long) (Wrd106.Lng))))
    goto label_215;
  (Wrd86.uLng) = (OBJECT_DATUM (Wrd97.Obj));
  (Wrd91.pObj) = (& ((Wrd104.pObj) [(Wrd86.Lng)]));
  (Wrd94.Obj) = ((Wrd108.pObj) [3]);
  (Wrd95.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd96.Obj) = ((Wrd95.pObj) [0]);
  ((Wrd91.pObj) [1]) = (Wrd96.Obj);

DEFLABEL (label_214)
  (Wrd59.Obj) = (Rsp [0]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [3]);
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 26))
    goto label_213;
  (Wrd71.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
  (Wrd65.Lng) = ((Wrd71.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd65.Lng)))
    goto label_213;
  (Wrd72.Obj) = (LONG_TO_FIXNUM (Wrd65.Lng));
  (* (--Rsp)) = (Wrd72.Obj);

DEFLABEL (label_212)
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd75.Obj) = ((Wrd74.pObj) [3]);
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd75.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (* (--Rsp)) = (Wrd77.Obj);
  (Wrd82.Obj) = (Rsp [1]);
  ((Wrd76.pObj) [0]) = (Wrd82.Obj);
  Rvl = (Wrd77.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_213)
  (Wrd52.Obj) = (Rsp [0]);
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [3]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd51.Obj) = ((Wrd55.pObj) [0]);
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_128)
  (* (--Rsp)) = Rvl;
  goto label_212;

DEFLABEL (label_215)
  (Wrd112.Obj) = (Rsp [0]);
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd111.Obj) = ((Wrd113.pObj) [2]);
  (Wrd114.Obj) = (Rsp [1]);
  (Wrd118.Obj) = ((Wrd113.pObj) [3]);
  (Wrd119.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  (Wrd115.Obj) = ((Wrd119.pObj) [0]);
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd114.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_129)
  goto label_214;

DEFLABEL (label_216)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_INTERFACE_0 (44);

DEFLABEL (label_127)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_210;
  goto label_211;

DEFLABEL (label_218)
  (Wrd39.Obj) = (Rsp [1]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_126)
  (Wrd25.Obj) = Rvl;
  goto label_217;

DEFLABEL (label_220)
  (Wrd21.Obj) = (current_block [OBJECT_11]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_125)
  (Wrd12.Obj) = Rvl;
  goto label_219;

DEFLABEL (label_222)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_34])), (Wrd7.pObj));

DEFLABEL (label_124)
  (Wrd6.Obj) = Rvl;
  goto label_221;

DEFLABEL (lambda_181)
  CLOSURE_HEADER (LABEL_31);

DEFLABEL (lambda_32)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd9.pObj) [0]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = ((SCHEME_OBJECT) 0);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 2);

DEFLABEL (lambda_182)
  CLOSURE_HEADER (LABEL_41);

DEFLABEL (lambda_51)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [3]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 2);

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_44);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_51);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_50])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  ((Wrd12.pObj) [3]) = Rvl;
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_224;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd24.Lng))))
    goto label_224;
  (Wrd18.Obj) = ((Wrd22.pObj) [10]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_223)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53]));

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_49);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_79);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_78])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [4]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd18.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80]));

DEFLABEL (label_224)
  (Wrd27.Obj) = (Rsp [4]);
  (Wrd28.Obj) = (current_block [OBJECT_14]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_130)
  (* (--Rsp)) = Rvl;
  goto label_223;

DEFLABEL (allocate_P_185)
DEFLABEL (allocate_P_102)
  INTERRUPT_CHECK (26, LABEL_47);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_272;
  Wrd6 = Wrd10;

DEFLABEL (label_271)
  Wrd5 = Wrd6;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_270;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd18.Lng))))
    goto label_270;
  (Wrd12.Obj) = ((Wrd16.pObj) [7]);

DEFLABEL (label_269)
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd37.uLng) == 10))
    goto label_268;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 26))
    goto label_268;
  (Wrd33.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd33.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_268;
  (Wrd27.uLng) = (OBJECT_DATUM (Wrd30.Obj));
  (Wrd29.pObj) = (& ((Wrd34.pObj) [(Wrd27.Lng)]));
  (Wrd25.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_267)
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd43.uLng) == 26))
    goto label_266;
  (Wrd177.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if ((Wrd177.Lng) == 0)
    goto label_265;

DEFLABEL (label_264)
  (Wrd51.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd54.Obj) = ((Wrd51.pObj) [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 50)
    goto label_263;
  Wrd50 = Wrd54;

DEFLABEL (label_262)
  Wrd49 = Wrd50;
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd63.uLng) == 10))
    goto label_261;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd61.Obj) = ((Wrd60.pObj) [0]);
  (Wrd62.Lng) = (FIXNUM_TO_LONG (Wrd61.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd62.Lng))))
    goto label_261;
  (Wrd56.Obj) = ((Wrd60.pObj) [7]);

DEFLABEL (label_260)
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd81.uLng) == 10))
    goto label_259;
  (Wrd74.Obj) = (Rsp [1]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd75.uLng) == 26))
    goto label_259;
  (Wrd77.Lng) = (FIXNUM_TO_LONG (Wrd74.Obj));
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd79.Obj) = ((Wrd78.pObj) [0]);
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd79.Obj));
  if (! (((unsigned long) (Wrd77.Lng)) < ((unsigned long) (Wrd80.Lng))))
    goto label_259;
  (Wrd71.uLng) = (OBJECT_DATUM (Wrd74.Obj));
  (Wrd73.pObj) = (& ((Wrd78.pObj) [(Wrd71.Lng)]));
  (Wrd69.Obj) = ((Wrd73.pObj) [1]);

DEFLABEL (label_258)
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if (! ((Wrd87.uLng) == 26))
    goto label_257;
  (Wrd174.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  if ((Wrd174.Lng) == 0)
    goto label_255;

DEFLABEL (label_254)
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd98.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd101.Obj) = ((Wrd98.pObj) [0]);
  (Wrd102.uLng) = (OBJECT_TYPE (Wrd101.Obj));
  if ((Wrd102.uLng) == 50)
    goto label_253;
  Wrd97 = Wrd101;

DEFLABEL (label_252)
  Wrd96 = Wrd97;
  (Wrd110.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd110.uLng) == 10))
    goto label_251;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd97.Obj));
  (Wrd108.Obj) = ((Wrd107.pObj) [0]);
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd108.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd109.Lng))))
    goto label_251;
  (Wrd103.Obj) = ((Wrd107.pObj) [7]);

DEFLABEL (label_250)
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if (! ((Wrd128.uLng) == 10))
    goto label_249;
  (Wrd121.Obj) = (Rsp [1]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if (! ((Wrd122.uLng) == 26))
    goto label_249;
  (Wrd124.Lng) = (FIXNUM_TO_LONG (Wrd121.Obj));
  (Wrd125.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd126.Obj) = ((Wrd125.pObj) [0]);
  (Wrd127.Lng) = (FIXNUM_TO_LONG (Wrd126.Obj));
  if (! (((unsigned long) (Wrd124.Lng)) < ((unsigned long) (Wrd127.Lng))))
    goto label_249;
  (Wrd117.uLng) = (OBJECT_DATUM (Wrd121.Obj));
  (Wrd119.pObj) = (& ((Wrd125.pObj) [(Wrd117.Lng)]));
  (Wrd120.Obj) = ((Wrd119.pObj) [1]);
  (* (--Rsp)) = (Wrd120.Obj);

DEFLABEL (label_248)
  (Wrd136.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd139.Obj) = ((Wrd136.pObj) [0]);
  (Wrd140.uLng) = (OBJECT_TYPE (Wrd139.Obj));
  if ((Wrd140.uLng) == 50)
    goto label_247;
  Wrd135 = Wrd139;

DEFLABEL (label_246)
  Wrd134 = Wrd135;
  (Wrd148.uLng) = (OBJECT_TYPE (Wrd135.Obj));
  if (! ((Wrd148.uLng) == 10))
    goto label_245;
  (Wrd145.pObj) = (OBJECT_ADDRESS (Wrd135.Obj));
  (Wrd146.Obj) = ((Wrd145.pObj) [0]);
  (Wrd147.Lng) = (FIXNUM_TO_LONG (Wrd146.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd147.Lng))))
    goto label_245;
  (Wrd141.Obj) = ((Wrd145.pObj) [5]);

DEFLABEL (label_244)
  (Wrd166.uLng) = (OBJECT_TYPE (Wrd141.Obj));
  if (! ((Wrd166.uLng) == 10))
    goto label_243;
  (Wrd159.Obj) = (Rsp [2]);
  (Wrd160.uLng) = (OBJECT_TYPE (Wrd159.Obj));
  if (! ((Wrd160.uLng) == 26))
    goto label_243;
  (Wrd162.Lng) = (FIXNUM_TO_LONG (Wrd159.Obj));
  (Wrd163.pObj) = (OBJECT_ADDRESS (Wrd141.Obj));
  (Wrd164.Obj) = ((Wrd163.pObj) [0]);
  (Wrd165.Lng) = (FIXNUM_TO_LONG (Wrd164.Obj));
  if (! (((unsigned long) (Wrd162.Lng)) < ((unsigned long) (Wrd165.Lng))))
    goto label_243;
  (Wrd155.uLng) = (OBJECT_DATUM (Wrd159.Obj));
  (Wrd157.pObj) = (& ((Wrd163.pObj) [(Wrd155.Lng)]));
  (Wrd158.Obj) = ((Wrd157.pObj) [1]);
  (* (--Rsp)) = (Wrd158.Obj);

DEFLABEL (label_242)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_96)
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_241;
  Wrd10 = Wrd14;

DEFLABEL (label_240)
  Wrd9 = Wrd10;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd23.uLng) == 10))
    goto label_239;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) 6L) < ((unsigned long) (Wrd22.Lng))))
    goto label_239;
  (Wrd16.Obj) = ((Wrd20.pObj) [7]);

DEFLABEL (label_238)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd41.uLng) == 10))
    goto label_237;
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 26))
    goto label_237;
  (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) (Wrd37.Lng)) < ((unsigned long) (Wrd40.Lng))))
    goto label_237;
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd34.Obj));
  (Wrd32.pObj) = (& ((Wrd38.pObj) [(Wrd30.Lng)]));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_236)
  (Wrd49.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd52.Obj) = ((Wrd49.pObj) [0]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if ((Wrd53.uLng) == 50)
    goto label_235;
  Wrd48 = Wrd52;

DEFLABEL (label_234)
  Wrd47 = Wrd48;
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd61.uLng) == 10))
    goto label_233;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd59.Obj) = ((Wrd58.pObj) [0]);
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd59.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd60.Lng))))
    goto label_233;
  (Wrd54.Obj) = ((Wrd58.pObj) [5]);

DEFLABEL (label_232)
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd79.uLng) == 10))
    goto label_231;
  (Wrd72.Obj) = (Rsp [3]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd73.uLng) == 26))
    goto label_231;
  (Wrd75.Lng) = (FIXNUM_TO_LONG (Wrd72.Obj));
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd77.Obj) = ((Wrd76.pObj) [0]);
  (Wrd78.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  if (! (((unsigned long) (Wrd75.Lng)) < ((unsigned long) (Wrd78.Lng))))
    goto label_231;
  (Wrd68.uLng) = (OBJECT_DATUM (Wrd72.Obj));
  (Wrd70.pObj) = (& ((Wrd76.pObj) [(Wrd68.Lng)]));
  (Wrd71.Obj) = ((Wrd70.pObj) [1]);
  (* (--Rsp)) = (Wrd71.Obj);

DEFLABEL (label_230)
  INVOKE_INTERFACE_0 (35);

DEFLABEL (continuation_101)
  (Rsp [1]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 26)
    goto label_226;

DEFLABEL (label_225)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_226)
  (Wrd10.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd10.uLng) == 26))
    goto label_225;
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Rvl));
  if ((Wrd12.Lng) < (Wrd14.Lng))
    goto label_228;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_227;

DEFLABEL (label_228)
  Rvl = (current_block [OBJECT_16]);

DEFLABEL (label_227)
DEFLABEL (label_229)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_231)
  (Wrd81.Obj) = (Rsp [3]);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_156)
  (* (--Rsp)) = Rvl;
  goto label_230;

DEFLABEL (label_233)
  (Wrd63.Obj) = (current_block [OBJECT_11]);
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_155)
  (Wrd54.Obj) = Rvl;
  goto label_232;

DEFLABEL (label_235)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_87])), (Wrd49.pObj));

DEFLABEL (label_154)
  (Wrd48.Obj) = Rvl;
  goto label_234;

DEFLABEL (label_237)
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_153)
  (* (--Rsp)) = Rvl;
  goto label_236;

DEFLABEL (label_239)
  (Wrd25.Obj) = (current_block [OBJECT_15]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_152)
  (Wrd16.Obj) = Rvl;
  goto label_238;

DEFLABEL (label_241)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_84])), (Wrd11.pObj));

DEFLABEL (label_151)
  (Wrd10.Obj) = Rvl;
  goto label_240;

DEFLABEL (label_243)
  (Wrd168.Obj) = (Rsp [2]);
  (Wrd171.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70]))));
  (* (--Rsp)) = (Wrd171.Obj);
  (* (--Rsp)) = (Wrd168.Obj);
  (* (--Rsp)) = (Wrd141.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_144)
  (* (--Rsp)) = Rvl;
  goto label_242;

DEFLABEL (label_245)
  (Wrd150.Obj) = (current_block [OBJECT_11]);
  (Wrd153.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69]))));
  (* (--Rsp)) = (Wrd153.Obj);
  (* (--Rsp)) = (Wrd150.Obj);
  (* (--Rsp)) = (Wrd134.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_143)
  (Wrd141.Obj) = Rvl;
  goto label_244;

DEFLABEL (label_247)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_68])), (Wrd136.pObj));

DEFLABEL (label_142)
  (Wrd135.Obj) = Rvl;
  goto label_246;

DEFLABEL (label_249)
  (Wrd130.Obj) = (Rsp [1]);
  (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd133.Obj);
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_141)
  (* (--Rsp)) = Rvl;
  goto label_248;

DEFLABEL (label_251)
  (Wrd112.Obj) = (current_block [OBJECT_15]);
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_140)
  (Wrd103.Obj) = Rvl;
  goto label_250;

DEFLABEL (label_253)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_65])), (Wrd98.pObj));

DEFLABEL (label_139)
  (Wrd97.Obj) = Rvl;
  goto label_252;

DEFLABEL (label_255)
  Rvl = (current_block [OBJECT_16]);

DEFLABEL (label_256)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_257)
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_138)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_254;
  goto label_255;

DEFLABEL (label_259)
  (Wrd83.Obj) = (Rsp [1]);
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_137)
  (Wrd69.Obj) = Rvl;
  goto label_258;

DEFLABEL (label_261)
  (Wrd65.Obj) = (current_block [OBJECT_15]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_136)
  (Wrd56.Obj) = Rvl;
  goto label_260;

DEFLABEL (label_263)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60])), (Wrd51.pObj));

DEFLABEL (label_135)
  (Wrd50.Obj) = Rvl;
  goto label_262;

DEFLABEL (label_265)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_256;

DEFLABEL (label_266)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_134)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_264;
  goto label_265;

DEFLABEL (label_268)
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_133)
  (Wrd25.Obj) = Rvl;
  goto label_267;

DEFLABEL (label_270)
  (Wrd21.Obj) = (current_block [OBJECT_15]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_132)
  (Wrd12.Obj) = Rvl;
  goto label_269;

DEFLABEL (label_272)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56])), (Wrd7.pObj));

DEFLABEL (label_131)
  (Wrd6.Obj) = Rvl;
  goto label_271;

DEFLABEL (renumbered_registers_186)
DEFLABEL (renumbered_registers_83)
  INTERRUPT_CHECK (26, LABEL_72);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_282;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 26))
    goto label_282;
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd84.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  if ((Wrd80.Lng) < (Wrd84.Lng))
    goto label_274;

DEFLABEL (label_273)
  Rvl = (current_block [OBJECT_17]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_274)
  (Wrd67.Obj) = (Rsp [1]);
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd69.Obj) = ((Wrd68.pObj) [1]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if (! ((Wrd70.uLng) == 10))
    goto label_281;
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 26))
    goto label_281;
  (Wrd60.Lng) = (FIXNUM_TO_LONG (Wrd57.Obj));
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd69.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (Wrd66.Lng) = (FIXNUM_TO_LONG (Wrd65.Obj));
  if (! (((unsigned long) (Wrd60.Lng)) < ((unsigned long) (Wrd66.Lng))))
    goto label_281;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd57.Obj));
  (Wrd27.pObj) = (& ((Wrd64.pObj) [(Wrd22.Lng)]));
  (Wrd28.Obj) = ((Wrd27.pObj) [1]);
  if ((Wrd28.Obj) == ((SCHEME_OBJECT) 0))
    goto label_278;

DEFLABEL (label_277)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd44.pObj)));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 26))
    goto label_276;
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd51.Obj));
  (Wrd53.Lng) = ((Wrd55.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd53.Lng)))
    goto label_276;
  (Wrd56.Obj) = (LONG_TO_FIXNUM (Wrd53.Lng));
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_275)
  goto renumbered_registers_83;

DEFLABEL (label_276)
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_147)
  (* (--Rsp)) = Rvl;
  goto label_275;

DEFLABEL (label_278)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 26))
    goto label_280;
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  (Wrd37.Lng) = ((Wrd39.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd37.Lng)))
    goto label_280;
  (Wrd34.Obj) = (LONG_TO_FIXNUM (Wrd37.Lng));

DEFLABEL (label_279)
  (Rsp [0]) = (Wrd34.Obj);
  goto label_275;

DEFLABEL (label_280)
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_146)
  (Wrd34.Obj) = Rvl;
  goto label_279;

DEFLABEL (label_281)
  (Wrd72.Obj) = (Rsp [1]);
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  (Wrd71.Obj) = ((Wrd73.pObj) [1]);
  (Wrd74.Obj) = (Rsp [0]);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_148)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_278;
  goto label_277;

DEFLABEL (label_282)
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [2]);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_145)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_273;
  goto label_274;

DEFLABEL (continuation_82)
  INTERRUPT_CHECK (27, LABEL_76);
  (Wrd10.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_183)
  CLOSURE_HEADER (LABEL_50);

DEFLABEL (lambda_38)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_285;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_285;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) (Wrd16.Lng)) < ((unsigned long) (Wrd22.Lng))))
    goto label_285;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd11.pObj) = (& ((Wrd20.pObj) [(Wrd6.Lng)]));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_284)
  (Wrd34.Obj) = (Rsp [0]);
  if ((Wrd34.Obj) == ((SCHEME_OBJECT) 0))
    goto label_283;
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [3]);
  (Rsp [1]) = (Wrd36.Obj);
  (Rsp [2]) = (Wrd34.Obj);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_18]), 2);

DEFLABEL (label_283)
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_285)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_149)
  (* (--Rsp)) = Rvl;
  goto label_284;

DEFLABEL (lambda_184)
  CLOSURE_HEADER (LABEL_54);

DEFLABEL (lambda_72)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_287;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_287;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) (Wrd16.Lng)) < ((unsigned long) (Wrd22.Lng))))
    goto label_287;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd11.pObj) = (& ((Wrd20.pObj) [(Wrd6.Lng)]));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_286)
  (Wrd34.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto loop_70;

DEFLABEL (label_287)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_150)
  (* (--Rsp)) = Rvl;
  goto label_286;

DEFLABEL (lambda_187)
  CLOSURE_HEADER (LABEL_78);

DEFLABEL (lambda_49)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_91])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [4]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_90);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_302;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_302;
  (Wrd10.Obj) = ((Wrd14.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_301)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_104])));
  Rhp += 2;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd30 = Wrd25;
  (Wrd31.Obj) = (Rsp [2]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [2]);
  ((Wrd30.pObj) [2]) = (Wrd33.Obj);
  (Wrd29.Obj) = ((Wrd32.pObj) [4]);
  ((Wrd30.pObj) [3]) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_102);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 10))
    goto label_300;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd19.Lng))))
    goto label_300;
  (Wrd11.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_299)
  (Rsp [2]) = (Wrd11.Obj);
  (Wrd27.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd27.Obj);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_298;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [0]);

DEFLABEL (label_297)
  if ((Wrd28.Obj) == (current_block [OBJECT_23]))
    goto label_288;
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_288)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd44.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_115);
  (* (--Rsp)) = Rvl;
  (Wrd9.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd9.uLng) == 1))
    goto label_296;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_295)
  if ((Wrd5.Obj) == (current_block [OBJECT_25]))
    goto label_289;
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_289)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116]));

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_119);
  (Rsp [0]) = Rvl;
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd7.uLng) == 26))
    goto label_294;
  (Wrd9.Lng) = (FIXNUM_TO_LONG (Rvl));
  if (! ((Wrd9.Lng) < 5L))
    goto label_291;

DEFLABEL (label_290)
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_291)
  (Wrd12.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 10))
    goto label_293;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_293;
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  if (! (((unsigned long) (Wrd22.Lng)) < ((unsigned long) (Wrd26.Lng))))
    goto label_293;
  (Wrd15.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd18.pObj) = (& ((Wrd24.pObj) [(Wrd15.Lng)]));
  (Wrd13.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_292)
  (Rsp [3]) = (Wrd13.Obj);
  Rsp = (& (Rsp [2]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_18]), 2);

DEFLABEL (label_293)
  (Wrd29.Obj) = (Rsp [3]);
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_173)
  (Wrd13.Obj) = Rvl;
  goto label_292;

DEFLABEL (label_294)
  (Wrd38.Obj) = (current_block [OBJECT_13]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_174)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_291;
  goto label_290;

DEFLABEL (label_296)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_172)
  (Wrd5.Obj) = Rvl;
  goto label_295;

DEFLABEL (label_298)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_22]), 1);

DEFLABEL (label_170)
  (Wrd28.Obj) = Rvl;
  goto label_297;

DEFLABEL (label_300)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.Obj) = (current_block [OBJECT_4]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_169)
  (Wrd11.Obj) = Rvl;
  goto label_299;

DEFLABEL (label_302)
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.Obj) = (current_block [OBJECT_19]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_161)
  (* (--Rsp)) = Rvl;
  goto label_301;

DEFLABEL (loop_189)
DEFLABEL (loop_70)
  INTERRUPT_CHECK (26, LABEL_93);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_323;
  (Wrd7.Obj) = (Rsp [2]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [6]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_323;
  (Wrd128.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd134.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  if ((Wrd128.Lng) < (Wrd134.Lng))
    goto label_316;

DEFLABEL (label_315)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [6]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd23.Obj) = ((Wrd27.pObj) [0]);
  (Rsp [0]) = (Wrd23.Obj);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd42.uLng) == 26))
    goto label_314;
  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  (Wrd43.Lng) = ((Wrd49.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd43.Lng)))
    goto label_314;
  (Wrd36.Obj) = (LONG_TO_FIXNUM (Wrd43.Lng));

DEFLABEL (label_313)
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [6]);
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  ((Wrd53.pObj) [0]) = (Wrd36.Obj);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd60.Obj) = ((Wrd51.pObj) [3]);
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [0]);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12]), 2);

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_96);
  (Wrd5.Obj) = Rvl;
  (Wrd95.Obj) = (Rsp [2]);
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd97.Obj) = ((Wrd96.pObj) [5]);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
  if (! ((Wrd98.uLng) == 10))
    goto label_312;
  (Wrd85.Obj) = (Rsp [0]);
  (Wrd86.uLng) = (OBJECT_TYPE (Wrd85.Obj));
  if (! ((Wrd86.uLng) == 26))
    goto label_312;
  (Wrd88.Lng) = (FIXNUM_TO_LONG (Wrd85.Obj));
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd97.Obj));
  (Wrd93.Obj) = ((Wrd92.pObj) [0]);
  (Wrd94.Lng) = (FIXNUM_TO_LONG (Wrd93.Obj));
  if (! (((unsigned long) (Wrd88.Lng)) < ((unsigned long) (Wrd94.Lng))))
    goto label_312;
  (Wrd79.uLng) = (OBJECT_DATUM (Wrd85.Obj));
  (Wrd84.pObj) = (& ((Wrd92.pObj) [(Wrd79.Lng)]));
  ((Wrd84.pObj) [1]) = Rvl;

DEFLABEL (label_311)
  (Wrd110.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd110.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_310;
  Wrd9 = Wrd13;

DEFLABEL (label_309)
  Wrd8 = Wrd9;
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd22.uLng) == 10))
    goto label_308;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd21.Lng))))
    goto label_308;
  (Wrd15.Obj) = ((Wrd19.pObj) [4]);

DEFLABEL (label_307)
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd71.uLng) == 10))
    goto label_306;
  (Wrd64.Obj) = (Rsp [3]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 26))
    goto label_306;
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd64.Obj));
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd69.Obj) = ((Wrd68.pObj) [0]);
  (Wrd70.Lng) = (FIXNUM_TO_LONG (Wrd69.Obj));
  if (! (((unsigned long) (Wrd67.Lng)) < ((unsigned long) (Wrd70.Lng))))
    goto label_306;
  (Wrd60.uLng) = (OBJECT_DATUM (Wrd64.Obj));
  (Wrd62.pObj) = (& ((Wrd68.pObj) [(Wrd60.Lng)]));
  (Wrd63.Obj) = (Rsp [0]);
  ((Wrd62.pObj) [1]) = (Wrd63.Obj);

DEFLABEL (label_305)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [5]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 10))
    goto label_304;
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 26))
    goto label_304;
  (Wrd39.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (Wrd45.Lng) = (FIXNUM_TO_LONG (Wrd44.Obj));
  if (! (((unsigned long) (Wrd39.Lng)) < ((unsigned long) (Wrd45.Lng))))
    goto label_304;
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd36.Obj));
  (Wrd35.pObj) = (& ((Wrd43.pObj) [(Wrd30.Lng)]));
  (Wrd28.Obj) = ((Wrd35.pObj) [1]);

DEFLABEL (label_303)
  (Rsp [2]) = (Wrd28.Obj);
  (Wrd57.Obj) = (Rsp [1]);
  (Rsp [3]) = (Wrd57.Obj);
  Rsp = (& (Rsp [2]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_18]), 2);

DEFLABEL (label_304)
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [5]);
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_165)
  (Wrd28.Obj) = Rvl;
  goto label_303;

DEFLABEL (label_306)
  (Wrd73.Obj) = (Rsp [3]);
  (Wrd74.Obj) = (Rsp [0]);
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_166)
  goto label_305;

DEFLABEL (label_308)
  (Wrd24.Obj) = (current_block [OBJECT_8]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_164)
  (Wrd15.Obj) = Rvl;
  goto label_307;

DEFLABEL (label_310)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_109])), (Wrd10.pObj));

DEFLABEL (label_163)
  (Wrd9.Obj) = Rvl;
  goto label_309;

DEFLABEL (label_312)
  (Wrd100.Obj) = (Rsp [2]);
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd99.Obj) = ((Wrd101.pObj) [5]);
  (Wrd102.Obj) = (Rsp [0]);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_9]), 3);

DEFLABEL (label_167)
  goto label_311;

DEFLABEL (label_314)
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [6]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd32.pObj) [0]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_158)
  (Wrd36.Obj) = Rvl;
  goto label_313;

DEFLABEL (label_316)
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd87.Obj) = (Rsp [4]);
  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd87.Obj));
  (Wrd89.Obj) = ((Wrd88.pObj) [5]);
  (Wrd90.uLng) = (OBJECT_TYPE (Wrd89.Obj));
  if (! ((Wrd90.uLng) == 10))
    goto label_322;
  (Wrd77.Obj) = (Rsp [2]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 26))
    goto label_322;
  (Wrd80.Lng) = (FIXNUM_TO_LONG (Wrd77.Obj));
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd85.Obj) = ((Wrd84.pObj) [0]);
  (Wrd86.Lng) = (FIXNUM_TO_LONG (Wrd85.Obj));
  if (! (((unsigned long) (Wrd80.Lng)) < ((unsigned long) (Wrd86.Lng))))
    goto label_322;
  (Wrd70.uLng) = (OBJECT_DATUM (Wrd77.Obj));
  (Wrd75.pObj) = (& ((Wrd84.pObj) [(Wrd70.Lng)]));
  (Wrd76.Obj) = ((Wrd75.pObj) [1]);
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_321)
  (Wrd116.Obj) = (Rsp [5]);
  (Wrd117.pObj) = (OBJECT_ADDRESS (Wrd116.Obj));
  (Wrd118.Obj) = ((Wrd117.pObj) [4]);
  (Wrd119.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if (! ((Wrd119.uLng) == 10))
    goto label_320;
  (Wrd106.Obj) = (Rsp [4]);
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd106.Obj));
  if (! ((Wrd107.uLng) == 26))
    goto label_320;
  (Wrd109.Lng) = (FIXNUM_TO_LONG (Wrd106.Obj));
  (Wrd113.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  (Wrd114.Obj) = ((Wrd113.pObj) [0]);
  (Wrd115.Lng) = (FIXNUM_TO_LONG (Wrd114.Obj));
  if (! (((unsigned long) (Wrd109.Lng)) < ((unsigned long) (Wrd115.Lng))))
    goto label_320;
  (Wrd99.uLng) = (OBJECT_DATUM (Wrd106.Obj));
  (Wrd104.pObj) = (& ((Wrd113.pObj) [(Wrd99.Lng)]));
  (Wrd105.Obj) = ((Wrd104.pObj) [1]);
  (* (--Rsp)) = (Wrd105.Obj);

DEFLABEL (label_319)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101]));

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_98);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_21]), 1);

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_97);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_311;
  (Wrd116.Obj) = (Rsp [0]);
  (Wrd117.uLng) = (OBJECT_TYPE (Wrd116.Obj));
  if (! ((Wrd117.uLng) == 26))
    goto label_318;
  (Wrd120.Lng) = (FIXNUM_TO_LONG (Wrd116.Obj));
  (Wrd118.Lng) = ((Wrd120.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd118.Lng)))
    goto label_318;
  (Wrd115.Obj) = (LONG_TO_FIXNUM (Wrd118.Lng));

DEFLABEL (label_317)
  (Rsp [0]) = (Wrd115.Obj);
  goto loop_70;

DEFLABEL (label_318)
  (Wrd111.Obj) = (Rsp [0]);
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_107]))));
  (* (--Rsp)) = (Wrd114.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_168)
  (Wrd115.Obj) = Rvl;
  goto label_317;

DEFLABEL (label_320)
  (Wrd121.Obj) = (Rsp [5]);
  (Wrd122.pObj) = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd120.Obj) = ((Wrd122.pObj) [4]);
  (Wrd123.Obj) = (Rsp [4]);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100]))));
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd120.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_160)
  (* (--Rsp)) = Rvl;
  goto label_319;

DEFLABEL (label_322)
  (Wrd92.Obj) = (Rsp [4]);
  (Wrd93.pObj) = (OBJECT_ADDRESS (Wrd92.Obj));
  (Wrd91.Obj) = ((Wrd93.pObj) [5]);
  (Wrd94.Obj) = (Rsp [2]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_159)
  (* (--Rsp)) = Rvl;
  goto label_321;

DEFLABEL (label_323)
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [6]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd18.pObj) [0]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_157)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_315;
  goto label_316;

DEFLABEL (lambda_188)
  CLOSURE_HEADER (LABEL_91);

DEFLABEL (lambda_41)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd28.Obj) = ((Wrd6.pObj) [2]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 10))
    goto label_325;
  (Wrd16.Obj) = (Rsp [2]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 26))
    goto label_325;
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd19.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_325;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd16.Obj));
  (Wrd15.pObj) = (& ((Wrd23.pObj) [(Wrd10.Lng)]));
  (Wrd8.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_324)
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd37.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_20]), 2);

DEFLABEL (label_325)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [2]);
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_162)
  (Wrd8.Obj) = Rvl;
  goto label_324;

DEFLABEL (lambda_190)
  CLOSURE_HEADER (LABEL_104);

DEFLABEL (lambda_45)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 10))
    goto label_328;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_328;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  if (! (((unsigned long) (Wrd16.Lng)) < ((unsigned long) (Wrd22.Lng))))
    goto label_328;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd13.Obj));
  (Wrd11.pObj) = (& ((Wrd20.pObj) [(Wrd6.Lng)]));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_327)
  (Wrd34.Obj) = (Rsp [0]);
  if ((Wrd34.Obj) == ((SCHEME_OBJECT) 0))
    goto label_326;
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [3]);
  (Rsp [1]) = (Wrd36.Obj);
  (Rsp [2]) = (Wrd34.Obj);
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_24]), 2);

DEFLABEL (label_326)
  Rvl = (current_block [OBJECT_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_328)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_5]), 2);

DEFLABEL (label_171)
  (* (--Rsp)) = Rvl;
  goto label_327;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

int
decl_ralloc_so_2e0edaa2f68719e7 (void)
{
  return (0);
}

DECLARE_COMPILED_CODE ("ralloc.so", 99, decl_ralloc_so_2e0edaa2f68719e7, ralloc_so_2e0edaa2f68719e7)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_ralloc_so_data_2e0edaa2f68719e7 [1307] =
  "\xff\x01\x02\x81\x02\x1d\x0c\x0d\xc2\x0d\xc1\xc1\xc2\x81\xc2\x08"
  "\x07\x86\x02\x85\xc2\x84\x82\xc3\x83\x0c\x02\xc2\x80\x1d\xc3\xc3"
  "\x0d\x0d\xb8\x25\xb0\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73"
  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
  "\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
  "\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f"
  "\x72\x74\x6c\x6f\x70\x74\x2f\x72\x61\x6c\x6c\x6f\x63\x2e\x69\x6e"
  "\x66\x09\x72\x65\x67\x69\x73\x74\x65\x72\x12\x62\x69\x74\x2d\x73"
  "\x74\x72\x69\x6e\x67\x2d\x63\x6c\x65\x61\x72\x21\x07\x61\x73\x73"
  "\x69\x67\x6e\x04\x63\x61\x72\x11\x62\x69\x74\x2d\x73\x74\x72\x69"
  "\x6e\x67\x2d\x7a\x65\x72\x6f\x3f\x0f\x62\x69\x74\x2d\x73\x74\x72"
  "\x69\x6e\x67\x2d\x6f\x72\x21\x10\x62\x69\x74\x2d\x73\x74\x72\x69"
  "\x6e\x67\x2d\x73\x65\x74\x21\x0a\x10\x6d\x61\x6b\x65\x2d\x62\x69"
  "\x74\x2d\x73\x74\x72\x69\x6e\x67\x0c\x76\x65\x63\x74\x6f\x72\x2d"
  "\x73\x65\x74\x21\x1e\x54\x6f\x6f\x20\x6d\x61\x6e\x79\x20\x74\x65"
  "\x6d\x70\x6f\x72\x61\x72\x79\x20\x71\x75\x61\x6e\x74\x69\x74\x69"
  "\x65\x73\xc1\x84\x3d\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66"
  "\x02\x13\x6c\x65\x78\x69\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e"
  "\x6d\x65\x6e\x74\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67"
  "\x6e\x6d\x65\x6e\x74\x14\x72\x65\x67\x69\x73\x74\x65\x72\x2d\x61"
  "\x6c\x6c\x6f\x63\x61\x74\x69\x6f\x6e\x11\x2a\x63\x75\x72\x72\x65"
  "\x6e\x74\x2d\x72\x67\x72\x61\x70\x68\x2a\x02\x02\x04\x09\x66\x6f"
  "\x72\x2d\x65\x61\x63\x68\x04\x0c\x6d\x61\x6b\x65\x2d\x76\x65\x63"
  "\x74\x6f\x72\x04\x06\x65\x72\x72\x6f\x72\x05\x13\x73\x68\x61\x6c"
  "\x6c\x6f\x77\x2d\x66\x6c\x75\x69\x64\x2d\x62\x69\x6e\x64\x03\x19"
  "\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d\x70\x73\x65\x75\x64\x6f\x2d"
  "\x72\x65\x67\x69\x73\x74\x65\x72\x04\x18\x6d\x61\x6b\x65\x2d\x69"
  "\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x64\x2d\x76\x65\x63\x74\x6f"
  "\x72\x04\x17\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d\x72\x65\x67\x73"
  "\x65\x74\x2d\x6d\x65\x6d\x62\x65\x72\x04\x05\x73\x6f\x72\x74\x04"
  "\x14\x62\x62\x6c\x6f\x63\x6b\x2d\x77\x61\x6c\x6b\x2d\x66\x6f\x72"
  "\x77\x61\x72\x64\x04\x0f\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67"
  "\x2d\x61\x6e\x64\x04\x10\x67\x65\x6e\x65\x72\x61\x6c\x2d\x63\x61"
  "\x72\x2d\x63\x64\x72\x0c\x63\xc8\x01\x80\x80\x04\x62\xc6\x01\x81"
  "\x81\x02\x61\xc4\x01\x81\x89\x02\x60\xc2\x01\x81\x89\x02\x5f\xc0"
  "\x01\x81\x89\x02\x5e\xbe\x01\x81\x89\x02\x5d\xbc\x01\x81\x87\x02"
  "\x5c\xba\x01\x81\x85\x02\x5b\xb8\x01\x81\x85\x02\x5a\xb6\x01\x81"
  "\x87\x02\x59\xb4\x01\x81\x89\x02\x58\xb2\x01\x81\x85\x02\x57\xb0"
  "\x01\x81\x8b\x02\x56\xae\x01\x81\x89\x02\x55\xac\x01\x81\x89\x02"
  "\x54\xaa\x01\x81\x89\x02\x53\xa8\x01\x81\x89\x02\x52\xa6\x01\x81"
  "\x89\x02\x51\xa4\x01\x81\x89\x02\x50\xa2\x01\x81\x89\x02\x4f\xa0"
  "\x01\x81\x89\x02\x4e\x9e\x01\x81\x87\x02\x4d\x9c\x01\x81\x85\x02"
  "\x4c\x9a\x01\x81\x87\x02\x4b\x98\x01\x81\x85\x02\x4a\x96\x01\x81"
  "\x85\x02\x49\x94\x01\x81\x8f\x02\x48\x92\x01\x81\x8d\x02\x47\x90"
  "\x01\x81\x89\x02\x46\x8e\x01\x81\x89\x02\x45\x8c\x01\x81\x89\x02"
  "\x44\x8a\x01\x81\x85\x02\x43\x88\x01\x81\x85\x02\x42\x86\x01\x81"
  "\x89\x02\x41\x84\x01\x81\x89\x02\x40\x82\x01\x81\x89\x02\x3f\x80"
  "\x01\x81\x87\x02\x3e\x7e\x81\x87\x02\x3d\x7c\x81\x87\x02\x3c\x7a"
  "\x81\x85\x02\x3b\x78\x81\x85\x02\x3a\x76\x81\x85\x02\x39\x74\x81"
  "\x85\x02\x38\x72\x81\x85\x02\x37\x70\x81\x87\x02\x36\x6e\x81\x89"
  "\x02\x35\x6c\x81\x85\x02\x34\x6a\x81\x85\x02\x33\x68\x81\x85\x02"
  "\x32\x66\x81\x85\x02\x31\x64\x81\x95\x02\x30\x62\x81\x89\x02\x2f"
  "\x60\x81\x89\x02\x2e\x5e\x81\x89\x02\x2d\x5c\x81\x87\x02\x2c\x5a"
  "\x81\x87\x02\x2b\x58\x81\x87\x02\x2a\x56\x81\x85\x02\x29\x54\x81"
  "\x85\x02\x28\x52\x81\x85\x02\x27\x50\x81\x85\x02\x26\x4e\x81\x85"
  "\x02\x25\x4c\x81\x85\x02\x24\x4a\x81\x85\x02\x23\x48\x81\x85\x02"
  "\x22\x46\x84\x06\x21\x44\x81\x91\x02\x20\x42\x81\x8f\x02\x1f\x40"
  "\x81\x8b\x02\x1e\x3e\x81\x85\x02\x1d\x3c\x81\x8b\x02\x1c\x3a\x81"
  "\x85\x02\x1b\x38\x81\x8b\x02\x1a\x36\x81\x85\x02\x19\x34\x81\x89"
  "\x02\x18\x32\x81\x85\x02\x17\x30\x81\x85\x02\x16\x2e\x81\x85\x02"
  "\x15\x2c\x81\x85\x02\x14\x2a\x81\x85\x02\x13\x28\x81\x85\x02\x12"
  "\x26\x81\x85\x02\x11\x24\x81\x89\x02\x10\x22\x81\x85\x02\x0f\x20"
  "\x81\x83\x02\x0e\x1e\x81\x85\x02\x0d\x1c\x81\x83\x02\x0c\x1a\x81"
  "\x83\x02\x0b\x18\x81\x85\x02\x0a\x16\x81\x83\x02\x09\x14\x81\x85"
  "\x02\x08\x12\x81\x85\x02\x07\x10\x81\x83\x02\x06\x0e\x81\x83\x02"
  "\x05\x0c\x81\x83\x02\x04\x0a\x83\x04\x03\x08\x83\x04\x02\x06\x81"
  "\x83\x02\x01\x04\x81\x83\x02\xc7\x01\xff\x01";

SCHEME_OBJECT *
ralloc_so_data_2e0edaa2f68719e7 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_ralloc_so_data_2e0edaa2f68719e7 [0]))), (sizeof (prog_ralloc_so_data_2e0edaa2f68719e7)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_123]));
}

DECLARE_COMPILED_DATA_NS ("ralloc.so", ralloc_so_data_2e0edaa2f68719e7)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("ralloc.so", "98efefc5fe8cf0d1")
